@@ -103,7 +103,7 @@ class InnerPanel(wx.Panel):
         self.combo_interval.SetSelection(0)
 
         inner_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        inner_sizer.AddSizer(btnsizer, 0, wx.LEFT|wx.TOP, 5)
+        inner_sizer.Add(btnsizer, 0, wx.LEFT|wx.TOP, 5)
         inner_sizer.Add(self.combo_interval, 0, wx.LEFT|wx.RIGHT|wx.TOP, 5)
         panel.SetSizer(inner_sizer)
         inner_sizer.Fit(panel)
@@ -129,9 +129,9 @@ class InnerPanel(wx.Panel):
         Publisher.subscribe(self.ShowDicomPreview, "Load import panel")
         Publisher.subscribe(self.GetSelectedImages ,"Selected Import Images")  
 
-    def GetSelectedImages(self, pubsub_evt):
-        self.first_image_selection = pubsub_evt.data[0]
-        self.last_image_selection = pubsub_evt.data[1]
+    def GetSelectedImages(self, selection):
+        self.first_image_selection = selection[0]
+        self.last_image_selection = selection[1]
         
     def _bind_events(self):
         self.Bind(EVT_SELECT_SERIE, self.OnSelectSerie)
@@ -141,8 +141,7 @@ class InnerPanel(wx.Panel):
         self.btn_cancel.Bind(wx.EVT_BUTTON, self.OnClickCancel)
         self.text_panel.Bind(EVT_SELECT_SERIE_TEXT, self.OnDblClickTextPanel)
 
-    def ShowDicomPreview(self, pubsub_evt):
-        dicom_groups = pubsub_evt.data
+    def ShowDicomPreview(self, dicom_groups):
         self.patients.extend(dicom_groups)
         self.text_panel.Populate(dicom_groups)
 
@@ -187,8 +186,9 @@ class InnerPanel(wx.Panel):
 
         nslices_result = slice_amont / (interval + 1)
         if (nslices_result > 1):
-            Publisher.sendMessage('Open DICOM group', (group, interval, 
-                                    [self.first_image_selection, self.last_image_selection]))
+            Publisher.sendMessage('Open DICOM group', group=group,
+                                  interval=interval,
+                                  file_range=(self.first_image_selection, self.last_image_selection))
         else:
             dlg.MissingFilesForReconstruction()
 
@@ -215,7 +215,7 @@ class TextPanel(wx.Panel):
                                    wx.TR_DEFAULT_STYLE
                                    | wx.TR_HIDE_ROOT
                                    | wx.TR_ROW_LINES
-                                   | wx.TR_COLUMN_LINES
+                                   #  | wx.TR_COLUMN_LINES
                                    | wx.TR_FULL_ROW_HIGHLIGHT
                                    | wx.TR_SINGLE
                                   )
@@ -251,8 +251,8 @@ class TextPanel(wx.Panel):
         self.root = tree.AddRoot(_("InVesalius Database"))
         self.tree = tree
 
-    def SelectSeries(self, pubsub_evt):
-        group_index = pubsub_evt.data
+    def SelectSeries(self, group_index):
+        pass
 
     def Populate(self, patient_list):
         tree = self.tree
@@ -313,7 +313,7 @@ class TextPanel(wx.Panel):
             group = self.tree.GetItemPyData(item)
             if isinstance(group, dcm.DicomGroup):
                 Publisher.sendMessage('Load group into import panel',
-                                            group)
+                                            group=group)
 
             elif isinstance(group, dcm.PatientGroup):
                 id = group.GetDicomSample().patient.id
@@ -322,7 +322,7 @@ class TextPanel(wx.Panel):
                 self.GetEventHandler().ProcessEvent(my_evt)
 
                 Publisher.sendMessage('Load patient into import panel',
-                                            group)
+                                            patient=group)
         else:
             parent_id = self.tree.GetItemParent(item)
             self.tree.Expand(parent_id)
@@ -362,7 +362,8 @@ class ImagePanel(wx.Panel):
         splitter.SetOrientation(wx.HORIZONTAL)
         self.splitter = splitter
 
-        splitter.ContainingSizer = wx.BoxSizer(wx.HORIZONTAL)
+        # TODO Rever isso
+        #  splitter.ContainingSizer = wx.BoxSizer(wx.HORIZONTAL)
 
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.Add(splitter, 1, wx.EXPAND)
@@ -429,8 +430,7 @@ class SeriesPanel(wx.Panel):
         self.serie_preview.Bind(dpp.EVT_CLICK_SERIE, self.OnSelectSerie)
         self.dicom_preview.Bind(dpp.EVT_CLICK_SLICE, self.OnSelectSlice)
 
-    def SetDicomSeries(self, pubsub_evt):
-        group = pubsub_evt.data
+    def SetDicomSeries(self, group):
         self.dicom_preview.SetDicomGroup(group)
         self.dicom_preview.Show(1)
         self.serie_preview.Show(0)
@@ -440,9 +440,7 @@ class SeriesPanel(wx.Panel):
     def GetSelectedImagesRange(self):
         return [self.dicom_preview.first_selected, self.dicom_preview_last_selection]
 
-    def SetPatientSeries(self, pubsub_evt):
-        patient = pubsub_evt.data
-
+    def SetPatientSeries(self, patient):
         self.dicom_preview.Show(0)
         self.serie_preview.Show(1)
 
@@ -473,8 +471,7 @@ class SeriesPanel(wx.Panel):
         my_evt.SetItemData(evt.GetItemData())
         self.GetEventHandler().ProcessEvent(my_evt)
 
-    def ShowDicomSeries(self, pubsub_evt):
-        patient = pubsub_evt.data
+    def ShowDicomSeries(self, patient):
         if isinstance(patient, dcm.PatientGroup):
             self.serie_preview.SetPatientGroups(patient)
             self.dicom_preview.SetPatientGroups(patient)
@@ -504,21 +501,18 @@ class SlicePanel(wx.Panel):
         self.SetAutoLayout(1)
         self.sizer = sizer
 
-    def SetPatientSeries(self, pubsub_evt):
-        patient = pubsub_evt.data
+    def SetPatientSeries(self, patient):
         group = patient.GetGroups()[0]
         self.dicom_preview.SetDicomGroup(group)
         self.sizer.Layout()
         self.Update()
 
-    def SetDicomSeries(self, evt):
-        group = evt.data
+    def SetDicomSeries(self, group):
         self.dicom_preview.SetDicomGroup(group)
         self.sizer.Layout()
         self.Update()
 
-    def ShowDicomSeries(self, pubsub_evt):
-        patient = pubsub_evt.data
+    def ShowDicomSeries(self, patient):
         group = patient.GetGroups()[0]
         self.dicom_preview.SetDicomGroup(group)
         self.sizer.Layout()
