@@ -229,18 +229,16 @@ class InnerFoldPanel(wx.Panel):
     def __bind_events(self):
         Publisher.subscribe(self.OnCheckStatus, 'Navigation status')
         Publisher.subscribe(self.OnShowObject, 'Update track object state')
-        Publisher.subscribe(self.OnVolumeCamera, 'Target navigation mode')
+        Publisher.subscribe(self.OnVolumeCamera, 'Change camera checkbox')
         Publisher.subscribe(self.OnShowDbs, "Active dbs folder")
         Publisher.subscribe(self.OnHideDbs, "Deactive dbs folder")
 
     def OnShowDbs(self):
         self.dbs_item.Show()
 
-
     def OnHideDbs(self):
         self.dbs_item.Hide()
 
-
     def OnCheckStatus(self, status):
         if status:
             self.checktrigger.Enable(False)
@@ -257,6 +255,7 @@ class InnerFoldPanel(wx.Panel):
         if not evt:
             if flag:
                 self.checkobj.Enable(True)
+                self.checkobj.SetValue(True)
                 self.track_obj = True
                 Publisher.sendMessage('Status target button', status=True)
             else:
@@ -267,12 +266,12 @@ class InnerFoldPanel(wx.Panel):
 
         Publisher.sendMessage('Update show object state', state=self.checkobj.GetValue())
 
-    def OnVolumeCamera(self, evt=None, target_mode=None):
+    def OnVolumeCamera(self, evt=None, status=None):
         if not evt:
-            if target_mode is True:
-                self.checkcamera.SetValue(0)
+            self.checkcamera.SetValue(status)
         Publisher.sendMessage('Update volume camera state', camera_state=self.checkcamera.GetValue())
 
+
 class NeuronavigationPanel(wx.Panel):
     def __init__(self, parent):
         wx.Panel.__init__(self, parent)
@@ -453,7 +452,7 @@ class NeuronavigationPanel(wx.Panel):
         if hasattr(evt, 'GetSelection'):
             choice = evt.GetSelection()
         else:
-            choice = 6
+            choice = const.DISCTRACK
 
         if self.trk_init:
             trck = self.trk_init[0]
@@ -462,7 +461,7 @@ class NeuronavigationPanel(wx.Panel):
 
         # Conditions check if click was on current selection and if any other tracker
         # has been initialized before
-        if trck and choice != 6:
+        if trck and choice != const.DISCTRACK:
             self.ResetTrackerFiducials()
             Publisher.sendMessage('Update status text in GUI',
                                   label=_("Disconnecting tracker..."))
@@ -480,7 +479,7 @@ class NeuronavigationPanel(wx.Panel):
                 else:
                     ctrl.SetSelection(self.tracker_id)
                     print("Tracker connected!")
-        elif choice == 6:
+        elif choice == const.DISCTRACK:
             if trck:
                 self.ResetTrackerFiducials()
                 Publisher.sendMessage('Update status text in GUI',
@@ -890,6 +889,10 @@ class ObjectRegistrationPanel(wx.Panel):
                                               data=(self.obj_fiducials, self.obj_orients, self.obj_ref_mode, self.obj_name))
                         Publisher.sendMessage('Update status text in GUI',
                                               label=_("Ready"))
+                        # Enable automatically Track object, Show coil and disable Vol. Camera
+                        self.checktrack.SetValue(True)
+                        Publisher.sendMessage('Update track object state', flag=True, obj_name=self.obj_name)
+                        Publisher.sendMessage('Change camera checkbox', status=False)
 
             except wx._core.PyAssertionError:  # TODO FIX: win64
                 pass
@@ -916,6 +919,9 @@ class ObjectRegistrationPanel(wx.Panel):
             Publisher.sendMessage('Update object registration',
                                   data=(self.obj_fiducials, self.obj_orients, self.obj_ref_mode, self.obj_name))
             Publisher.sendMessage('Update status text in GUI', label=_("Ready"))
+            self.checktrack.SetValue(True)
+            Publisher.sendMessage('Update track object state', flag=True, obj_name=self.obj_name)
+            Publisher.sendMessage('Change camera checkbox', status=False)
             wx.MessageBox(_("Object file successfully loaded"), _("Load"))
 
     def ShowSaveObjectDialog(self, evt):
@@ -963,8 +969,8 @@ class MarkersPanel(wx.Panel):
         self.tgt_flag = self.tgt_index = None
         self.nav_status = False
 
-        self.marker_colour = (0.0, 0.0, 1.)
-        self.marker_size = 4
+        self.marker_colour = (1.0, 1.0, 0.)
+        self.marker_size = 3
 
         # Change marker size
         spin_size = wx.SpinCtrl(self, -1, "", size=wx.Size(40, 23))
@@ -1058,9 +1064,7 @@ class MarkersPanel(wx.Panel):
             self.nav_status = True
 
     def OnMouseRightDown(self, evt):
-        self.OnListEditMarkerId(self.nav_status)
-
-    def OnListEditMarkerId(self, status):
+        # TODO: Enable the "Set as target" only when target is created with registered object
         menu_id = wx.Menu()
         edit_id = menu_id.Append(0, _('Edit ID'))
         menu_id.Bind(wx.EVT_MENU, self.OnMenuEditMarkerId, edit_id)
@@ -1070,7 +1074,7 @@ class MarkersPanel(wx.Panel):
         target_menu = menu_id.Append(1, _('Set as target'))
         menu_id.Bind(wx.EVT_MENU, self.OnMenuSetTarget, target_menu)
 
-        target_menu.Enable(status)
+        target_menu.Enable(True)
         self.PopupMenu(menu_id)
         menu_id.Destroy()
 
