@@ -35,6 +35,9 @@ import imghdr
 
 import invesalius.utils as utils
 import invesalius.data.converters as converters
+from invesalius import inv_paths
+
+
 #flag to control vtk error in read files
 no_error = True 
 vtk_error = False
@@ -299,7 +302,7 @@ def ScipyRead(filepath):
 
 def VtkRead(filepath, t):
     if not const.VTK_WARNING:
-        log_path = os.path.join(const.USER_LOG_DIR, 'vtkoutput.txt')
+        log_path = os.path.join(inv_paths.USER_LOG_DIR, 'vtkoutput.txt')
         fow = vtk.vtkFileOutputWindow()
         fow.SetFileName(log_path.encode(const.FS_ENCODE))
         ow = vtk.vtkOutputWindow()
